import React, { SyntheticEvent } from 'react'
import { useTranslation } from 'react-i18next'
import { GestureResponderEvent, Platform, StyleSheet, View, ViewStyle, useWindowDimensions } from 'react-native'

import HoliIcon from '@holi/ui/components/atoms/HoliIcon'
import HoliLocalImage from '@holi/ui/components/atoms/HoliLocalImage'
import HoliText from '@holi/ui/components/atoms/HoliText'
import HoliButton from '@holi/ui/components/molecules/HoliButton'
import { colors } from '@holi/ui/styles/globalVars'

export interface SeeMoreProps {
  label?: string
  loading?: boolean
  onPress?: (event: SyntheticEvent<Element, Event> | GestureResponderEvent) => void
  style?: ViewStyle
  testID?: string
}

const SeeMore: React.VFC<SeeMoreProps> = ({ label, loading = false, onPress, style, testID }) => {
  const { t } = useTranslation()
  const { width: screenWidth } = useWindowDimensions()

  const labelSeeMore = label || t('global.seeMore')
  const cardImageSize = Platform.OS === 'web' ? 160 : screenWidth / 2 - 26

  return loading && Platform.OS !== 'web' ? (
    <View style={[style, styles.loadingContainer]}>
      <HoliIcon icon="loader-4" size={50} color={colors.foreground20} spinning />
    </View>
  ) : (
    <HoliButton
      label={labelSeeMore}
      style={[style, styles.button]}
      onPress={onPress}
      transparent
      inline
      testID={testID}
    >
      <HoliLocalImage
        imageSource={require('@holi/ui/assets/img/illustrations/illustration_see_more.png')}
        width={cardImageSize}
        height={cardImageSize}
        label=""
      />
      <View style={styles.textWrapper}>
        <HoliText style={styles.text} size="small" bold>
          {labelSeeMore}
        </HoliText>
      </View>
    </HoliButton>
  )
}

export default SeeMore

const styles = StyleSheet.create({
  loadingContainer: {
    width: 160,
    height: 160,
    borderRadius: 8,
    justifyContent: 'center',
    alignItems: 'center',
    backgroundColor: colors.background20,
  },
  button: {
    marginRight: Platform.OS === 'web' ? 24 : 48,
    flexDirection: 'column',
    justifyContent: 'space-between',
    flex: 1,
  },
  textWrapper: {
    flexDirection: 'row',
    justifyContent: 'center',
  },
  text: {
    color: colors.brandColorB30,
    textAlign: 'center',
    marginTop: 16,
  },
})
